package sysinfo

import (
	"encoding/json"
	"path/filepath"
	"strings"
)

// NetIface lives here.

type NetIface struct {
	Iface     string          `json:"iface"`
	IPAddr    json.RawMessage `json:"ip_addr"`
	Link      string          `json:"link"`
	Ethtool   string          `json:"ethtool,omitempty"`
	Stats     json.RawMessage `json:"statistics"`
	IPInfo    json.RawMessage `json:"ipinfo,omitempty"`
	Timestamp string          `json:"timestamp"`
}

func (a *App) collectNetwork(s *Snapshot, now string) error {
	defMap, _ := a.defaultIfaceSet()
	nets, _ := filepath.Glob("/sys/class/net/*")
	for _, n := range nets {
		if strings.HasSuffix(n, "/lo") {
			continue
		}
		iface := filepath.Base(n)
		mac := strings.ToLower(strings.ReplaceAll(
			a.safeRead(filepath.Join(n, "address")), ":", ""))
		if mac == "" {
			continue
		}

		nif := &NetIface{
			Iface:     iface,
			Timestamp: now,
		}
		_ = json.Unmarshal(
			a.runJSON(&nif.IPAddr, "ip", "-j", "address", "show", iface),
			&nif.IPAddr)
		nif.Link = a.safeRun("ip", "-details", "link", "show", iface)
		nif.Ethtool = a.safeRun("ethtool", iface)
		nif.Stats, _ = a.readNetStats(iface)
		if defMap[iface] {
			if o := a.safeRun("curl", "--interface", iface, "-s",
				"https://ipinfo.io"); json.Valid([]byte(o)) {
				nif.IPInfo = json.RawMessage(o)
			}
		}
		if s.Network == nil {
			s.Network = map[string]*NetIface{}
		}
		s.Network[mac] = nif
	}
	return nil
}
