package sysinfo

import "strings"

// ZPool represents details for one ZFS pool.
type ZPool struct {
	Timestamp string `json:"timestamp"`
	Status    string `json:"status"`
	Get       string `json:"get"`
	ZfsList   string `json:"zfs_list"`
}

func (a *App) collectZFS(s *Snapshot, now string) error {
	if a.safeRun("which", "zpool") == "" {
		return nil // ZFS not installed
	}
	pools := strings.Fields(a.safeRun("zpool", "list", "-H", "-o", "name"))
	if len(pools) == 0 {
		return nil
	}
	if s.ZFS == nil {
		s.ZFS = map[string]*ZPool{}
	}
	for _, p := range pools {
		z := &ZPool{Timestamp: now}
		z.Status = a.safeRun("zpool", "status", "-v", p)
		z.Get = a.safeRun("zpool", "get", "-H", "all", p)
		z.ZfsList = a.safeRun("zfs", "list", "-Hp", "-r", p)
		s.ZFS[p] = z
	}
	return nil
}
